---
title: "Community"
discription: "Open-source projects built with anywidget"
layout: "../../layouts/MainLayout.astro"
image:
  {
    src: "/teaser.png",
    alt: "Jupyter notebook with several anywidgets",
  }
---
import WidgetGallery from "../../components/WidgetGallery.astro"

## Widgets

**anywidget** powers several [open source
projects](https://github.com/manzt/anywidget/network/dependents). To feature
your **anywidget**, please [submit a
PR](https://github.com/manzt/built-with-anywidget/blob/main/assets/manifest.json).

<WidgetGallery />
